@@ -16,7 +16,7 @@ do
 
       difference1=$(awk '{print $1-$2}' <<< "$result1 $result2")
 
-      if (( $(echo $difference1#- $product | awk '{if ($1 < $2) print 1;}') )); 
+      if (( $(echo $difference1#- $product | awk '{if ($1 > $2) print 1;}') )); 
         then exit 1
       else echo "The results provided by $file and $file2 are the same within the threshold"; 
       fi
